@@ -16,7 +16,7 @@ from . import exceptions
 TOKEN_KEY = 'token'
 
 
-class BaseRequest(object):
+class BaseRequest:
     """
     This class provides an exclusive client to make HTTP requests to balena servers.
     This is low level class and is not meant to be used by end users directly.
@@ -163,7 +163,7 @@ class BaseRequest(object):
                     self.settings.get(TOKEN_KEY),
                     self.settings.get('token_refresh_interval')
                 ):
-                    self.settings.set(TOKEN_KEY, self._request_new_token())
+                    self.settings.set(TOKEN_KEY, self._request_new_token().decode())
             else:
                 # Auth Token not found
                 # Raise exception if this request requires logging in using credentials or Auth Token
@@ -213,7 +213,7 @@ class BaseRequest(object):
         return response.content
 
 
-class Util(object):
+class Util:
 
     def should_update_token(self, token, token_fresh_interval):
         try:
