@@ -19,7 +19,7 @@ def _normalize_device_type(dev_type):
     return dev_type
 
 
-class Config(object):
+class Config:
     """
     This class implements configuration model for balena python SDK.
 
@@ -61,6 +61,9 @@ class Config(object):
 
     def get_device_types(self):
         """
+        ***Deprecated***
+        This method is deprecated and will be removed in next major release.
+
         Get device types configuration.
 
         Returns:
